Attribute VB_Name = "modCC"
Option Explicit

'Common Control Classes (Use with CreateWindowEx)

Public Const ANIMATE_CLASS = "SysAnimate32"           'Creates animation controls. These controls silently display an audio video interleaved (AVI) clip.
Public Const DATETIMEPICK_CLASS = "SysDateTimePick32" 'Creates date and time picker controls. These controls provide a simple and intuitive interface to exchange date and time information with a user.
Public Const HOTKEY_CLASS = "msctls_hotkey32"         'Creates hot key controls. These controls make it easy for the user to define hot keys.
Public Const MONTHCAL_CLASS = "SysMonthCal32"         'Creates month calendar controls. These controls provide a simple and intuitive way for a user to select a date from a familiar interface.
Public Const PROGRESS_CLASS = "msctls_progress32"     'Creates progress bars. These controls indicate the progress of a lengthy operation.
Public Const REBARCLASSNAME = "ReBarWindow32"         'Creates rebar controls. These controls act as a container for child windows.
Public Const STATUSCLASSNAME = "msctls_statusbar32"   'Creates status windows. These controls display status information in a horizontal window.
Public Const TOOLBARCLASSNAME = "ToolbarWindow32"     'Creates toolbars. These controls contain buttons that carry out menu commands.
Public Const TOOLTIPS_CLASS = "tooltips_class32"      'Creates ToolTip controls. These controls display a small pop-up window containing a line of text that describes the purpose of a tool in an application.
Public Const TRACKBAR_CLASS = "msctls_trackbar32"     'Creates trackbars. These controls let the user select from a range of values by moving a slider.
Public Const UPDOWN_CLASS = "msctls_updown32"         'Creates up-down controls. These controls combine a pair of arrows with an edit control. Clicking the arrows increments or decrements the value in the edit control.
Public Const WC_COMBOBOXEX = "ComboBoxEx32"           'Creates ComboBoxEx controls. These controls provide an extension of the combo box control that provides native support for item images.
Public Const WC_HEADER32 = "SysHeader32"              'Creates header controls. These controls display headings at the top of columns of information and let the user sort the information by clicking the headings.
Public Const WC_IPADDRESS = "SysIPAddress32"          'Creates IP address controls. These controls are similar to an edit control, but they enable you to enter a numeric address in Internet protocol (IP) format.
Public Const WC_LISTVIEW = "SysListView32"            'Creates list-view controls. These controls display a collection of items, each consisting of an icon and a label, and provide several ways to arrange the items.
Public Const WC_PAGESCROLLER = "SysPager"             'Creates pager controls. These controls are used to contain and scroll another window.
Public Const WC_TABCONTROL = "SysTabControl32"        'Creates tab controls. These controls define multiple pages for the same area of a window or dialog box. Each page consists of a set of information or a group of controls that an application displays when the user selects the corresponding tab.
Public Const WC_TREEVIEW = "SysTreeView32"            'Creates tree-view controls. These controls display a hierarchical list of items. Each item consists of a label and an optional bitmap.
Public Const WC_NATIVEFONTCTL = "NativeFontCtl"       'native font control
Public Const WC_BUTTON = "Button"                     'checkbox ?
Public Const WC_STATIC = "Static"                     '?
Public Const WC_EDIT = "Edit"                         'edit?
Public Const WC_LISTBOX = "ListBox"                   '
Public Const WC_COMBOBOX = "ComboBox"                 '
Public Const WC_SCROLLBAR = "ScrollBar"               '
Public Const WC_LINK = "SysLink"                      '
'----------------------------------------------------------------------------------------
' Brought to you by:
'   Brad Martinez

' Initializes the entire common control dynamic-link library.
' Exported by all versions of Comctl32.dll.
Public Declare Sub InitCommonControls Lib "comctl32.dll" ()

' Initializes specific common controls classes from the common
' control dynamic-link library.
' Returns TRUE (non-zero) if successful, or FALSE otherwise.
' Began being exported with Comctl32.dll version 4.7 (IE3.0 & later).
Public Declare Function InitCommonControlsEx Lib "comctl32.dll" (lpInitCtrls As tagINITCOMMONCONTROLSEX) As Boolean

Type tagINITCOMMONCONTROLSEX   ' icc
    dwSize As Long   ' size of this structure
    dwICC As Long    ' flags indicating which classes to be initialized.
End Type

' Set of bit flags that indicate which common control classes will be loaded
' from the DLL. The dwICC value can be a combination of the following:

Public Const ICC_LISTVIEW_CLASSES = &H1      'listview, header
Public Const ICC_TREEVIEW_CLASSES = &H2      'treeview, tooltips
Public Const ICC_BAR_CLASSES = &H4           'toolbar, statusbar, trackbar, tooltips
Public Const ICC_TAB_CLASSES = &H8           'tab, tooltips
Public Const ICC_UPDOWN_CLASS = &H10         'updown
Public Const ICC_PROGRESS_CLASS = &H20       'progress bar
Public Const ICC_HOTKEY_CLASS = &H40         'hotkey
Public Const ICC_ANIMATE_CLASS = &H80        'animate control class
Public Const ICC_WIN95_CLASSES = &HFF        'loads everything above
Public Const ICC_DATE_CLASSES = &H100        'month picker, date picker, time picker, updown
Public Const ICC_USEREX_CLASSES = &H200      'comboex
Public Const ICC_COOL_CLASSES = &H400        'rebar (coolbar) control
Public Const ICC_INTERNET_CLASSES = &H800    'Load IP address class.
Public Const ICC_PAGESCROLLER_CLASS = &H1000 'Load pager control class.
Public Const ICC_NATIVEFNTCTL_CLASS = &H2000 'native font control
Public Const ICC_STANDARD_CLASSES = &H4000
Public Const ICC_LINK_CLASS = &H8000
Public Const ICC_ALL_CLASSES = &H7FFF        'but link-class

'====== Ranges for control message IDs =======================================

Public Const LVM_FIRST = &H1000                   ' ListView messages
Public Const TV_FIRST = &H1100                    ' TreeView messages
Public Const HDM_FIRST = &H1200                   ' Header messages
Public Const TCM_FIRST = &H1300                   ' Tab control messages
Public Const PGM_FIRST = &H1400                   ' Pager control messages
Public Const ECM_FIRST = &H1500                   ' Edit control messages
Public Const BCM_FIRST = &H1600                   ' Button control messages
Public Const CBM_FIRST = &H1700                   ' Combobox control messages

Public Const CCM_FIRST = &H2000                  ' Common control shared messages
Public Const CCM_LAST = (CCM_FIRST + &H200)

'====== COMMON CONTROL MESSAGES =====================
Public Const CCM_SETBKCOLOR = (CCM_FIRST + 1)         ' lParam is bkColor

Type tagCOLORSCHEME
   dwSize As Long
   clrBtnHighlight As Long 'COLORREF              ' highlight color
   clrBtnShadow As Long 'COLORREF                 ' shadow color
End Type

Public Const CCM_SETCOLORSCHEME = (CCM_FIRST + 2)     ' lParam is color scheme
Public Const CCM_GETCOLORSCHEME = (CCM_FIRST + 3)     ' fills in COLORSCHEME pointed to by lParam
Public Const CCM_GETDROPTARGET = (CCM_FIRST + 4)
Public Const CCM_SETUNICODEFORMAT = (CCM_FIRST + 5)
Public Const CCM_GETUNICODEFORMAT = (CCM_FIRST + 6)

'Public Const COMCTL32_VERSION = 6
Public Const COMCTL32_VERSION = 5

Public Const CCM_SETVERSION = (CCM_FIRST + &H7)
Public Const CCM_GETVERSION = (CCM_FIRST + &H8)
Public Const CCM_SETNOTIFYWINDOW = (CCM_FIRST + &H9)   ' wParam == hwndParent.
Public Const CCM_SETWINDOWTHEME = (CCM_FIRST + &HB)
Public Const CCM_DPISCALE = (CCM_FIRST + &HC)          ' wParam == Awareness

' for tooltips
Public Const INFOTIPSIZE = 1024

' '====== COMMON CONTROL STYLES =====================

' Following are the common control styles. Except where noted, these
' styles apply to header controls, toolbar controls, and status windows.

' Causes the control to position itself at the top of the parent window's client
' area and sets the width to be the same as the parent window's width.
' Toolbars have this style by default.
Public Const CCS_TOP = &H1&

' Causes the control to resize and move itself horizontally, but not vertically,
' in response to a WM_SIZE message. If CCS_NORESIZE is used, this style
' does not apply. Header windows have this style by default.
Public Const CCS_NOMOVEY = &H2&

' Causes the control to position itself at the bottom of the parent window's
' client area and sets the width to be the same as the parent window's width.
' Status windows have this style by default.
Public Const CCS_BOTTOM = &H3&

' Prevents the control from using the default width and height when setting its
' initial size or a new size. Instead, the control uses the width and height
' specified in the request for creation or sizing.
Public Const CCS_NORESIZE = &H4&

' Prevents the control from automatically moving to the top or bottom of the parent
' window. Instead, the control keeps its position within the parent window despite
' changes to the size of the parent. If CCS_TOP or CCS_BOTTOM is also used,
' the height is adjusted to the default, but the position and width remain unchanged.
Public Const CCS_NOPARENTALIGN = &H8&

' Prevents a one-pixel highlight from being drawn at the top of the control.
Public Const CCS_NOHILITE = &H10&

' Enables a toolbar's built-in customization features, which allow the user to drag
' a button to a new position or to remove a button by dragging it off the toolbar. In
' addition, the user can double-click the toolbar to display the Customize Toolbar
' dialog box, allowing the user to add, delete, and rearrange toolbar buttons.
Public Const CCS_ADJUSTABLE = &H20&

' Prevents a two-pixel highlight from being drawn at the top of the control.
Public Const CCS_NODIVIDER = &H40&

Public Const CCS_VERT = &H80&
Public Const CCS_LEFT = (CCS_VERT Or CCS_TOP)
Public Const CCS_RIGHT = (CCS_VERT Or CCS_BOTTOM)
Public Const CCS_NOMOVEX = (CCS_VERT Or CCS_NOMOVEY)

' =============================================

' At some point early on in the status bar's life this message may have been supported
' but apparenty is not anymore...
' From "Win32 Common Controls, Part 2: Status Bars and Toolbars"
' Nancy Winnick Cluts. Microsoft Developer Network Technology Group, March 1994

' The SB_SETBORDERS message sets the widths of the horizontal and vertical borders
' of a status bar or header window. These borders determine the spacing between the
' outer edge of the window and the rectangles within the window that contain text, and the
' spacingbetween rectangles.
' wParam = 0, not used
' lParam = The address of an integer array that has three elements. The first element
'               specifies the width of the horizontal border, the second specifies the width of
'               the vertical border, and the third specifies the width of the border between
'               rectangles. If an element is set to 1, the default width for the border is used.
' Rtns True on success, False if failure
'Public Const SB_SETBORDERS = (WM_USER + ?)

' =============================================================

'----------------------------------------------------------------------------------------
' Brought to you by:
'   Brad Martinez

' Returns True if the current working version of Comctl32.dll is
' available on the system and the new IE3 sytles and messages
' can be used. Returns False either if the old version is present or
' Comctl32.dll isn't available at all. Also ensures that the library is
' loaded for use.

' We can get away with this hack rather than checking the file's
' version because VB resolves declared API function names only
' when they're called, not when it compiles the code...

Public Function InitComctl32(dwFlags As Long) As Boolean

  Dim icc As tagINITCOMMONCONTROLSEX
  On Error GoTo Err_OldVersion
  
  icc.dwSize = Len(icc)
  icc.dwICC = dwFlags
  
  ' VB will generate error 453 "Specified DLL function not found"
  ' here if the new version isn't installed and it can't find the function's
  ' name. We'll hopefully be able to load the old version below...
  InitComctl32 = InitCommonControlsEx(icc)
  Exit Function

Err_OldVersion:
  InitCommonControls

End Function

